==> gbsite-1.0.0.tar.gz: gbsite/htdocs/member/memjoin.php <==
<?

/**************************************************
Program name:	memjoin.php  
Author:		Allen McGrath (allen@greatbridge.com)

Description:	initial input screen for the member joining
		process.  it performs the following:

		1.  make sure the user is not already a member. ---DONE
		2.  retrieves needed reference data.  -- DONE
		3.  retrieves template.  -- DONE

Create Date:		9/20/00 

Modified Date(s):	
	9/27/00 allen@greatbridge.com
		-- changed misspelled variable ($country) in member update
                   sql statement and reformatted it.
							 
**************************************************/
 
/******************************************
 CHECK TO SEE IF THE PERSON IS ALREADY A
 MEMBER.  IF SO, SEND THEM TO CONTEXT AND LEAVE. OTHER
 WISE PROCEED AS PLANNED. 
*******************************************/
$web_page = "memjoinpage";
include("site_info.php");

if ($member_id) {
	$context = "You are already a registered member of ". $official_name . ".  If you want to create a new account, log out first.";
	$web_page = "contextpage";
	include($page_template);
	return;
}	
	
/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
$do_debug = "no";

/******************************************
	RETRIEVE THE REFERENCE DATA
*******************************************/	

	$st_query  = "SELECT STATE_CODE, STATE_NAME FROM STATE ORDER BY STATE_CODE";
	$st_result = pg_exec($conn,$st_query);
	$st_count  = pg_numrows($st_result);
	
	$cn_query  = "SELECT COUNTRY_CODE, COUNTRY_NAME FROM COUNTRY WHERE COUNTRY_CODE = 'US' " .
		     "UNION ALL (SELECT COUNTRY_CODE, COUNTRY_NAME FROM COUNTRY " .
		     "WHERE COUNTRY_CODE <> 'US')";
	$cn_result = pg_exec($conn,$cn_query);	

if ($do_debug == "yes") {
	echo "<li>state query = " . $st_query . "<br>";
	echo "<li>cntry query = " . $cn_query . "<br>";
}

	$r = 0;
	while ($row = @pg_fetch_array($st_result,$r++)) {
		$states[$row["state_code"]] = $row["state_name"];	
	}

	$r = 0;
	while ($row = @pg_fetch_array($cn_result,$r++)) {
		$countries[$row["country_code"]] = $row["country_name"];	

	}

/******************************************
ERROR CHECK VARIABLES IF THE REQUEST_METHOD
IS POST.
*******************************************/
if ($REQUEST_METHOD == "POST") {
	
	if ($do_debug == "yes") {
		echo "<li>member_name = " . $member_name . "<br>email = " . $email . "<br>password = " . $password;
	}
	
        $member_name = strtolower($member_name);
	if (empty($member_name) || empty($email) || empty($password)) {
		$context_error[] = "The user name, email, and password fields are mandatory.";
	}
	
	if (!empty($email) && !eregi("^[_\.0-9a-z-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) { 
		$context_error[] = "Your email address does not appear to be in a correct format."; 
	} 	
	
	if ($password <> $password_check) {
		$context_error[] = "Your password does not match.";
	}
	

// SINCE THESE ARE NOT REQUIRED, THEY NEED DEFAULTS SO WE DONT GET A DB ERROR	
	if (empty($state_code)) {
		$state_code = 'VA';
	}
	if (empty($country_code)) {
		$country_code = 'USA';
	}
		
	if (count($context_error)) {
		$context = "There was a problem with the information you submitted.  Specifically:";
		include($page_template);
		return;
	}


/******************************************
ALL OF THE VARIABLE CHECKS ARE DONE.  NOW
CHECK THE DATABASE FOR UNIQUE CONFLICTS AND 
INS/UPDATE SCENARIOS.
*******************************************/
	$chk_query = "SELECT REGISTER_ID FROM MEMBER WHERE REGISTER_ID = '$register_id'";
	$chk_result = pg_exec($conn,$chk_query);
	
	if (pg_numrows($chk_result) == 1) {
		$db_scenario = "UPDATE";
	}
	else {
		$db_scenario = "INSERT";
	}

	
/******************************************
 NO BLATANT ERRORS.  REFORMAT THE DATA AND
 INSERT/UPDATE THE INFORMATION

*******************************************/
	$member_name   = strtolower($member_name);
	$email         = strtolower($email);
	$first_name    = ucfirst(strtolower($first_name));
	$last_name     = ucfirst(strtolower($last_name));
	$password_orig = $password; 
	$password      = crypt($password,$password);
	$city          = ucfirst(strtolower($city));

        if ($db_scenario == "INSERT") {
            # check to make sure that the username specified is not already being used.
            $query = "select count(*) from member where member_name = '$member_name'";
            $res   = pg_exec($conn,$query);
            $found_existing_name = pg_result($res,0,0);
            pg_freeresult($res);
            if($found_existing_name)
                $context_error[] = "Sorry, according to our records, we've already got a member with that username.  Please choose another one.";

            # check to make sure the email specified is not already being used.
            $query = "select count(*) from member where email = '$email'";
            $res   = pg_exec($conn,$query);
            $found_existing_email = pg_result($res,0,0);
            pg_freeresult($res);
            if($found_existing_email)
                $context_error[] = "Sorry, according to our records, we've already got a member with that email address.  If that's you, please log in.";

            if(!empty($context_error)) {
                $context = "There was an error handling your request. ".
                           " Please <a href=/about/contact.php>Contact Us</a> ".
                           " regarding this and we will fix the problem.";
                include($page_template);
                return;
            }

            $mem_query = "INSERT INTO MEMBER (REGISTER_ID,MEMBER_NAME,PASSWORD,HINT,EMAIL, ".
                         "       FIRST_NAME,LAST_NAME,ADDR_1,ADDR_2,CITY,ZIP_CODE,STATE_CODE, ".
                         "       COUNTRY_CODE,AREA_CODE,PHONE,JOIN_DATE,LAST_UPDATED) " .
                         "VALUES ('$register_id','$member_name','$password','$hint','$email', ".
                         "        '$first_name','$last_name','$addr_1','$addr_2','$city','$zip_code', ".
                         "        '$state_code','$country_code','$area_code','$phone',now(),now())";
        } elseif (db_scenario == "UPDATE") {
            $mem_query = "UPDATE MEMBER SET MEMBER_NAME ='$member_name',PASSWORD = '$password', " .
                         "HINT = '$hint',EMAIL = '$email',FIRST_NAME = '$first_name'," .
                         "LAST_NAME = $last_name',ADDR_1 = '$addr_1'," .
                         "ADDR_2 = '$addr_2',CITY = '$city',ZIP_CODE = '$zip_code'," .
                         "STATE_CODE = '$state_code',COUNTRY_CODE = '$country_code'," .
                         "AREA_CODE = '$area_code',PHONE = '$phone'," .
                         "JOIN_DATE = now(),LAST_UPDATED = now()" .
                         "WHERE MEMBER_ID = $member_id";
        }
	
	if ($do_debug == "yes") {
		echo "<li>chk_query = " . $chk_query;
		echo "<li>num rows = " . pg_numrows($chk_result);
		echo "<li>query statement = " . $mem_query;
		echo "<li>scenario = " . $db_scenario;
	}

	$ins_result = @pg_exec($conn,$mem_query);
	$db_error = pg_errormessage($conn);

	if ($db_error) {
            $context = "There was an error handling your request. ".
                       " Please <a href=/about/contact.php>Contact Us</a> ".
                       " regarding this and we will fix the problem.";
            $context_error[] = $db_error;
            include($page_template);
            if ($do_debug == "yes") {
                echo "<li>web_page = " . $web_page;
                echo "<li>context = " . $context;
                echo "<li>context_error = " . $context_error[0];
                echo "<li>scenario = " . $db_scenario;
            }			
            return;
        }

/******************************************
SEND THE CONFIRMATION EMAIL HERE. THIS WILL
DIRECT THE USER TO A SCRIPT THAT VERIFIES
THE MEMBER VIA THE REGISTER_ID
*******************************************/
	elseif ($db_scenario == "INSERT") {
		$subj = "GreatBridge.org Member Confirmation";
		if ($do_debug == "yes") {
			echo "<li>Mail to: " . $email ;
			echo "<li>From: webmaster@greatbridge.org";
			echo "<li>Subj: " . $subj;
		}
		
		mail("$email","$subj",

"Dear $member_name,

Thank you for joining the $official_name community. To activate
your membership, please visit our confirmation page at:

http://www.$HTTP_HOST/member/memconfirm.php?$register_id

(please note that the URL above might have wrapped in your email
client, and you'll need to include the whole string.)

To access our site in the future, you will need the following
information:

Member Name: $member_name
Password:    $password_check

Please save this email for future reference.

Thanks again for joining our community. Please feel free to contact
me personally if you have any questions or suggestions about the
site or $official_name as a company.

Best regards,

Ned Lilly
VP Hacker Relations
Great Bridge, LLC
		", "From:webmaster@greatbridge.org");
		
	}

		$web_page = "contextpage";
		$context = "Thank you for joining our growing community.  We have sent a confirmation e-mail to $email, which is the last step in joining and receiving full benefits.  Once you respond to this email, your account will be activated, and you will have full access to the GreatBridge.org site and tools.
";

// END THE POST ACTION
} 


	
if (!$register_id) {
	$register_id = md5(time());
}

/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE	
******************************************/
  include($page_template);
 ?>

==> gbsite-1.1.1.tar.gz: gbsite/htdocs/member/memjoin.php <==
<?

/**************************************************
Program name:	memjoin.php  
Author:		Allen McGrath (allen@greatbridge.com)

Description:	initial input screen for the member joining
		process.  it performs the following:

		1.  make sure the user is not already a member. ---DONE
		2.  retrieves needed reference data.  -- DONE
		3.  retrieves template.  -- DONE

Create Date:		9/20/00 

Modified Date(s):	
	9/27/00 allen@greatbridge.com
		-- changed misspelled variable ($country) in member update
                   sql statement and reformatted it.
        12/20/2000 Chris Ryan <chris@greatbridge.com>
                -- modified the regexp for the email validation to except
                   + symbol in the name part of email email
                -- changed the email being sent to send "Great Bridge" if
                   the official_name of the site is "GreatBridge.org"
							 
**************************************************/
 
/******************************************
 CHECK TO SEE IF THE PERSON IS ALREADY A
 MEMBER.  IF SO, SEND THEM TO CONTEXT AND LEAVE. OTHER
 WISE PROCEED AS PLANNED. 
*******************************************/
$web_page = "memjoinpage";
include("site_info.php");

if ($member_id) {
	$context = "You are already a registered member of ". $official_name . ".  If you want to create a new account, log out first.";
	$web_page = "contextpage";
	include($page_template);
	return;
}	
	
/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
$do_debug = "no";

/******************************************
	RETRIEVE THE REFERENCE DATA
*******************************************/	

	$st_query  = "SELECT STATE_CODE, STATE_NAME FROM STATE ORDER BY STATE_CODE";
	$st_result = pg_exec($conn,$st_query);
	$st_count  = pg_numrows($st_result);
	
	$cn_query  = "SELECT COUNTRY_CODE, COUNTRY_NAME FROM COUNTRY WHERE COUNTRY_CODE = 'US' " .
		     "UNION ALL (SELECT COUNTRY_CODE, COUNTRY_NAME FROM COUNTRY " .
		     "WHERE COUNTRY_CODE <> 'US')";
	$cn_result = pg_exec($conn,$cn_query);	

if ($do_debug == "yes") {
	echo "<li>state query = " . $st_query . "<br>";
	echo "<li>cntry query = " . $cn_query . "<br>";
}

	$r = 0;
	while ($row = @pg_fetch_array($st_result,$r++)) {
		$states[$row["state_code"]] = $row["state_name"];	
	}

	$r = 0;
	while ($row = @pg_fetch_array($cn_result,$r++)) {
		$countries[$row["country_code"]] = $row["country_name"];	

	}

/******************************************
ERROR CHECK VARIABLES IF THE REQUEST_METHOD
IS POST.
*******************************************/
if ($REQUEST_METHOD == "POST") {
	
	if ($do_debug == "yes") {
		echo "<li>member_name = " . $member_name . "<br>email = " . $email . "<br>password = " . $password;
	}
	
        $member_name = strtolower($member_name);
	if (empty($member_name) || empty($email) || empty($password)) {
		$context_error[] = "The user name, email, and password fields are mandatory.";
	}
	
	if (!empty($email) && !eregi("^[_\.0-9a-z+-]+@([0-9a-z][-0-9a-z\.]+)\.([a-z]{2,3}$)", $email, $check)) { 
		$context_error[] = "Your email address does not appear to be in a correct format."; 
	} 	
	
	if ($password <> $password_check) {
		$context_error[] = "Your password does not match.";
	}
	

// SINCE THESE ARE NOT REQUIRED, THEY NEED DEFAULTS SO WE DONT GET A DB ERROR	
	if (empty($state_code)) {
		$state_code = 'VA';
	}
	if (empty($country_code)) {
		$country_code = 'USA';
	}
		
	if (count($context_error)) {
		$context = "There was a problem with the information you submitted.  Specifically:";
		include($page_template);
		return;
	}


/******************************************
ALL OF THE VARIABLE CHECKS ARE DONE.  NOW
CHECK THE DATABASE FOR UNIQUE CONFLICTS AND 
INS/UPDATE SCENARIOS.
*******************************************/
	$chk_query = "SELECT REGISTER_ID FROM MEMBER WHERE REGISTER_ID = '$register_id'";
	$chk_result = pg_exec($conn,$chk_query);
	
	if (pg_numrows($chk_result) == 1) {
		$db_scenario = "UPDATE";
	}
	else {
		$db_scenario = "INSERT";
	}

	
/******************************************
 NO BLATANT ERRORS.  REFORMAT THE DATA AND
 INSERT/UPDATE THE INFORMATION

*******************************************/
	$member_name   = strtolower($member_name);
	$email         = strtolower($email);
	$first_name    = ucfirst(strtolower($first_name));
	$last_name     = ucfirst(strtolower($last_name));
	$password_orig = $password; 
	$password      = crypt($password,$password);
	$city          = ucfirst(strtolower($city));

        if ($db_scenario == "INSERT") {
            # check to make sure that the username specified is not already being used.
            $query = "select count(*) from member where member_name = '$member_name'";
            $res   = pg_exec($conn,$query);
            $found_existing_name = pg_result($res,0,0);
            pg_freeresult($res);
            if($found_existing_name)
                $context_error[] = "Sorry, according to our records, we've already got a member with that username.  Please choose another one.";

            # check to make sure the email specified is not already being used.
            $query = "select count(*) from member where email = '$email'";
            $res   = pg_exec($conn,$query);
            $found_existing_email = pg_result($res,0,0);
            pg_freeresult($res);
            if($found_existing_email)
                $context_error[] = "Sorry, according to our records, we've already got a member with that email address.  If that's you, please log in.";

            if(!empty($context_error)) {
                $context = "There was an error handling your request. ".
                           " Please <a href=/about/contact.php>Contact Us</a> ".
                           " regarding this and we will fix the problem.";
                include($page_template);
                return;
            }

            $mem_query = "INSERT INTO MEMBER (REGISTER_ID,MEMBER_NAME,PASSWORD,HINT,EMAIL, ".
                         "       FIRST_NAME,LAST_NAME,ADDR_1,ADDR_2,CITY,ZIP_CODE,STATE_CODE, ".
                         "       COUNTRY_CODE,AREA_CODE,PHONE,JOIN_DATE,LAST_UPDATED) " .
                         "VALUES ('$register_id','$member_name','$password','$hint','$email', ".
                         "        '$first_name','$last_name','$addr_1','$addr_2','$city','$zip_code', ".
                         "        '$state_code','$country_code','$area_code','$phone',now(),now())";
        } elseif (db_scenario == "UPDATE") {
            $mem_query = "UPDATE MEMBER SET MEMBER_NAME ='$member_name',PASSWORD = '$password', " .
                         "HINT = '$hint',EMAIL = '$email',FIRST_NAME = '$first_name'," .
                         "LAST_NAME = $last_name',ADDR_1 = '$addr_1'," .
                         "ADDR_2 = '$addr_2',CITY = '$city',ZIP_CODE = '$zip_code'," .
                         "STATE_CODE = '$state_code',COUNTRY_CODE = '$country_code'," .
                         "AREA_CODE = '$area_code',PHONE = '$phone'," .
                         "JOIN_DATE = now(),LAST_UPDATED = now()" .
                         "WHERE MEMBER_ID = $member_id";
        }
	
	if ($do_debug == "yes") {
		echo "<li>chk_query = " . $chk_query;
		echo "<li>num rows = " . pg_numrows($chk_result);
		echo "<li>query statement = " . $mem_query;
		echo "<li>scenario = " . $db_scenario;
	}

	$ins_result = @pg_exec($conn,$mem_query);
	$db_error = pg_errormessage($conn);

	if ($db_error) {
            $context = "There was an error handling your request. ".
                       " Please <a href=/about/contact.php>Contact Us</a> ".
                       " regarding this and we will fix the problem.";
            $context_error[] = $db_error;
            include($page_template);
            if ($do_debug == "yes") {
                echo "<li>web_page = " . $web_page;
                echo "<li>context = " . $context;
                echo "<li>context_error = " . $context_error[0];
                echo "<li>scenario = " . $db_scenario;
            }			
            return;
        }

/******************************************
SEND THE CONFIRMATION EMAIL HERE. THIS WILL
DIRECT THE USER TO A SCRIPT THAT VERIFIES
THE MEMBER VIA THE REGISTER_ID
*******************************************/
	elseif ($db_scenario == "INSERT") {
		$subj = "GreatBridge.org Member Confirmation";
		if ($do_debug == "yes") {
			echo "<li>Mail to: " . $email ;
			echo "<li>From: webmaster@greatbridge.org";
			echo "<li>Subj: " . $subj;
		}
		
		mail("$email","$subj",

"Dear $member_name,

Thank you for joining the $official_name community. To activate
your membership, please visit our confirmation page at:

http://www.$HTTP_HOST/member/memconfirm.php?$register_id

(please note that the URL above might have wrapped in your email
client, and you'll need to include the whole string.)

To access our site in the future, you will need the following
information:

Member Name: $member_name
Password:    $password_check

Please save this email for future reference.

Thanks again for joining our community. Please feel free to contact
me personally if you have any questions or suggestions about the
site or " . ($official_name=="GreatBridge.org"?"Great Bridge":$official_name) . " as a company.

Best regards,

Ned Lilly
VP Hacker Relations
Great Bridge, LLC
		", "From:webmaster@greatbridge.org");
		
	}

		$web_page = "contextpage";
		$context = "Thank you for joining our growing community.  We have sent a confirmation e-mail to $email, which is the last step in joining and receiving full benefits.  Once you respond to this email, your account will be activated, and you will have full access to the GreatBridge.org site and tools.
";

// END THE POST ACTION
} 


	
if (!$register_id) {
	$register_id = md5(time());
}

/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE	
******************************************/
  include($page_template);
 ?>
